@@ -2,21 +2,23 @@ context("Comparative analysis")
 
 test_that("We can extract tree and trait data to run fitContinuous and fitDiscrete", {
   skip_if_not_installed("geiger")
+  
+  ## tests are too slow for CRAN
+  skip_on_cran()
 
   nexml <- read.nexml(system.file("examples", "comp_analysis.xml", package="RNeXML"))
   traits <- get_characters(nexml)
   tree <- get_trees(nexml)
   expect_is(tree, "phylo")
-  cts <- geiger::fitContinuous(tree, traits[1], ncores=1)
-  ## Incredibly, fitDiscrete cannot take discrete characters
-  # dte <- fitDiscrete(tree, traits[2], ncores=1)
-  traits[[2]] <- as.numeric(traits[[2]])
-  dte <- geiger::fitDiscrete(tree, traits[2], ncores=1)
+
   
 })
 
 
 test_that("We can serialize tree and trait data for a comparative analysis", {
+  ## tests are too slow for CRAN
+  skip_on_cran()
+  
   skip_if_not_installed("geiger")
 
   require("geiger")
